@@ -1,5 +1,5 @@
 package Yancy::Util;
-our $VERSION = '1.024';
+our $VERSION = '1.025';
 # ABSTRACT: Utilities for Yancy
 
 #pod =head1 SYNOPSIS
@@ -13,6 +13,11 @@ our $VERSION = '1.024';
 #pod     use Yancy::Util qw( currym );
 #pod     my $sub = currym( $object, 'method_name', @args );
 #pod
+#pod     use Yancy::Util qw( match );
+#pod     if ( match( $where, $item ) ) {
+#pod         say 'Matched!';
+#pod     }
+#pod
 #pod =head1 DESCRIPTION
 #pod
 #pod This module contains utility functions for Yancy.
@@ -25,10 +30,13 @@ our $VERSION = '1.024';
 
 use Mojo::Base '-strict';
 use Exporter 'import';
+use List::Util qw( any );
 use Mojo::Loader qw( load_class );
 use Scalar::Util qw( blessed );
 use Mojo::JSON::Pointer;
-our @EXPORT_OK = qw( load_backend curry currym copy_inline_refs );
+use Mojo::JSON qw( to_json );
+
+our @EXPORT_OK = qw( load_backend curry currym copy_inline_refs match );
 
 #pod =sub load_backend
 #pod
@@ -176,6 +184,68 @@ sub copy_inline_refs {
     );
 }
 
+#pod =sub match
+#pod
+#pod     my $bool = match( $where, $item );
+#pod
+#pod Test if the given C<$item> matches the given L<SQL::Abstract> C<$where>
+#pod data structure. See L<SQL::Abstract/WHERE CLAUSES> for the full syntax.
+#pod
+#pod Not all of SQL::Abstract's syntax is supported yet, so patches are welcome.
+#pod
+#pod =cut
+
+sub match {
+    my ( $match, $item ) = @_;
+
+    my %test;
+    for my $key ( keys %$match ) {
+        if ( $key =~ /^-(not_)?bool/ ) {
+            my $want_false = $1;
+            $key = $match->{ $key }; # the actual field
+            $test{ $key } = sub {
+                my ( $value, $key ) = @_;
+                return $want_false ? !$value : !!$value;
+            };
+        }
+        elsif ( !ref $match->{ $key } ) {
+            $test{ $key } = $match->{ $key };
+        }
+        elsif ( ref $match->{ $key } eq 'HASH' ) {
+            if ( my $value = $match->{ $key }{ -like } || $match->{ $key }{ like } ) {
+                $value = quotemeta $value;
+                $value =~ s/(?<!\\)\\%/.*/g;
+                $test{ $key } = qr{^$value$};
+            }
+            else {
+                die "Unimplemented query type: " . to_json( $match->{ $key } );
+            }
+        }
+        elsif ( ref $match->{ $key } eq 'ARRAY' ) {
+            my @tests = @{ $match->{ $key } };
+            # Array is an 'OR' combiner
+            $test{ $key } = sub {
+                my ( $value, $key ) = @_;
+                my $sub_item = { $key => $value };
+                return any { match( { $key => $_ }, $sub_item ) } @tests;
+            };
+        }
+        else {
+            die "Unimplemented match ref type: " . to_json( $match->{ $key } );
+        }
+    }
+
+    my $passes
+        = grep {
+            ref $test{ $_ } eq 'Regexp' ? $item->{ $_ } =~ $test{ $_ }
+            : ref $test{ $_ } eq 'CODE' ? $test{ $_ }->( $item->{ $_ }, $_ )
+            : $item->{ $_ } eq $test{ $_ }
+        }
+        keys %test;
+
+    return $passes == keys %test;
+}
+
 1;
 
 __END__
@@ -188,7 +258,7 @@ Yancy::Util - Utilities for Yancy
 
 =head1 VERSION
 
-version 1.024
+version 1.025
 
 =head1 SYNOPSIS
 
@@ -201,6 +271,11 @@ version 1.024
     use Yancy::Util qw( currym );
     my $sub = currym( $object, 'method_name', @args );
 
+    use Yancy::Util qw( match );
+    if ( match( $where, $item ) ) {
+        say 'Matched!';
+    }
+
 =head1 DESCRIPTION
 
 This module contains utility functions for Yancy.
@@ -277,6 +352,15 @@ will return another, copied standalone JSON schema, with any C<$ref>
 either copied in, or if previously encountered, with a C<$ref> to the
 new location.
 
+=head2 match
+
+    my $bool = match( $where, $item );
+
+Test if the given C<$item> matches the given L<SQL::Abstract> C<$where>
+data structure. See L<SQL::Abstract/WHERE CLAUSES> for the full syntax.
+
+Not all of SQL::Abstract's syntax is supported yet, so patches are welcome.
+
 =head1 SEE ALSO
 
 L<Yancy>
