@@ -13,7 +13,8 @@ CREATE TABLE "user" (
     email VARCHAR(255) NOT NULL,
     password VARCHAR(255) NOT NULL,
     access TEXT NOT NULL CHECK( access IN ( 'user', 'moderator', 'admin' ) ) DEFAULT 'user',
-    age INTEGER DEFAULT NULL
+    age INTEGER DEFAULT NULL,
+    plugin VARCHAR(50) NOT NULL DEFAULT 'password'
 );
 CREATE TABLE blog (
     id INTEGER PRIMARY KEY AUTOINCREMENT,
